%%Chemostat data of the strain K12GAPN+zwf+pPHB 
%AEROBIC
%% D 0.05
% Data Reconciliation
%% qrates mmol/gcdw h

clc
clear A_MT C Cx E E_in E_out gaps j J Mw q_m q_rec recovery S S_beta sd_q sd_qrec
variables={'oxygen'  'CO2'   'BM'  'glucose' 'acetate' 'lactate' 'ethanol' 'formate' 'succinate' 'PHB'};    
     
      % 1   2   3    4  5   6    7     8   9  
      % O2 CO2  BM  Glu Ace Lac Eth  For Succ 
     E=[ 0  1   1    6   2  3   2     1    4    ;
        -4  0   4.38 24  8  12  12    2   14  ]; 
     
A_MT = diag(ones(size(E,2),1)); 
C = [E;A_MT];

%Molecular weight of 1 Cmol of biomass
%Mw=24.44;

q_m = [-2.9406	2.8413	1.8888	-0.826	0.0072	0.0065	0.0297	0.0025	0.0066]';

% check on C and e balance raw data

for j =1:size( E,1 )
E_in = E(j,:) * min( q_m, 0 );
E_out = E(j,:) * max( q_m, 0 );
recovery(j) = E_out ./ -E_in * 100;
gaps(j) = E_in + E_out;
end

% 10% of error assumed for PHB quantification
sd_q = [-0.0525	0.053	0.0348	-0.0108	0.0009	0.001	0.0057	0.0007	0.0013]';

S = diag( [1e-9*ones(2,1); sd_q.^2 ]);
q_rec = inv(C'*inv(S)*C)*C'*inv(S)*[0;0;q_m];

% check calculations

for j =1:size( E,1 )
E_in = E(j,:) * min( q_rec, 0 );
E_out = E(j,:) * max( q_rec, 0 );
recovery(j) = E_out ./ -E_in * 100;
gaps(j) = E_in + E_out;
end

% estimtate errors in beta 
J = inv(C'*inv(S)*C)*C'*inv(S); 
S_beta = J * S * J';

sd_qrec = diag( S_beta ).^0.5;

% show rate +/- error
disp (variables')
disp( 'rate +/- error' )
disp( [q_rec sd_qrec] )

%% Calculate OUR and RQ with reconciled data 

RQ= q_rec(2)/q_rec(1);
RQ_STD= sqrt(sd_qrec(2)/q_rec(2))^2+((sd_qrec(1))/(q_rec(1))^2)*RQ;

qO2_qS = q_rec(1)/q_rec(4)
qO2_qS_STD= sqrt(sd_qrec(1)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qO2_qS;
b = [qO2_qS qO2_qS_STD];

Cx= 5.8333;%g/L
Cx_std= 0.146; %% g/L
Mx = 24.56;  %g/mol BIONUMBERS
glucose= 20*(180/198) ; %%g/L
OUR = q_rec(1)* Cx; %% mmolO2/Lh

OUR_std = sqrt(sd_qrec(1)/q_rec(1))^2 + ((Cx_std/Cx)^2)*OUR;  %%%

yield= Cx/glucose;   %%% gBM/gglucose
Y_BM = (q_rec(3)*Mx)/(q_rec(4)*180);
Y_BM_std = ((sd_qrec(3)/q_rec(3))^2)+((sd_qrec(4)/q_rec(4))^2);

a= [OUR OUR_std]
a1=[RQ RQ_STD ; Y_BM Y_BM_std]

% %Normalizing by products with their qby-p/qS for the Figure 										
qAce_n = q_rec(5)/q_rec(4);
qLac_n = q_rec(6)/q_rec(4);			
qEth_n = q_rec(7)/q_rec(4);	
qFor_n = q_rec(8)/q_rec(4);
qSucc_n = q_rec(9)/q_rec(4);

%Calculating standard deviations of ratio qby-p/qS
qAce_s = sqrt(sd_qrec(5)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qAce_n;
qLac_s = sqrt(sd_qrec(6)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qLac_n;			
qEth_s = sqrt(sd_qrec(7)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qEth_n;	
qFor_s = sqrt(sd_qrec(8)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qFor_n;
qSucc_s = sqrt(sd_qrec(9)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qSucc_n;

N_by_p= [qAce_n  qLac_n qEth_n qFor_n  qSucc_n ]'  %%mmol qi/qO2
N_by_p_s= [qAce_s  qLac_s qEth_s qFor_s qSucc_s ]'  %%mmol by-p/qS

