
clear all;
close all;
clc
%%%% Experimental results of the strain K12+pPHB   
%Chemostat at AEROBIC and OYGEN LIMITED CONDITIONS
%% tested at different dilution rates ~0.1 and ~0.05


%%Data_fixed
V_L = 0.98; % L broth
Glc_in = (20/198)*1000; %mmol/L of glucose
Glc = 20; %g/L of glucose
BM_MW= 24.56/1000; % g/mCmol considering CH1.73N0.24O0.35S0.006P0.005 Nikerel 2010
Vm = 22.4; % R*Tref/P; %L/mol Molar volume of air
pH_EC = 7;

%Excel file with the raw data
[num,lab,raw] = xlsread('Ecoli_PHB_1','data_PHB');

%%Gas phase 
Fair_in = num(:,19); % mmol/h
Fnitrogen_in = num(:,20); % mmol/h
yN2nitrogen_in = 1;
FNtotal=Fair_in+Fnitrogen_in; % mmol/h sum of mols of air and nitrogen
porcentFair= Fair_in./FNtotal;
yCO2_in = 0.0004; %fraction
yO2_in = 0.209; %fraction
yN2air_in = 1-yCO2_in-yO2_in; %fraction
y_CO2_out = num(:,3); % fraction
y_O2_out = num(:,4); % fraction


%%%Liquid phase
F_out = num(:,2)/1000; % L/h
F_in = F_out; %  L/h because of incorrect data of CO2 and O2 Fin could not be calculated
Glc_out = num(:,8); % glucose mmol/L
Lac = num(:,11); % lacate mmol/L
PHB = num(:,9); %  3-HB mmol/L
PHB_p = num(:,28); %  percentage of PHB in cells g/g
Eth = num(:,12); % ethanol mmol/L
Glyc= num(:,10); % glycerol mmol/L
Ace= num(:,13); % acetate mmol/L
Suc= num(:,14); % succinate mmol/l
For= num(:,15); % formate mmol/l
N_out = num(:,26); % mmolN/L
N_in= 113.06; % mmolN/L
BM = num(:,7)/BM_MW; % biomass mCmol/L (PHB already substracted)
BM_m = num(:,7) ; %biomass g/L
TOC_T = num(:,24); % mmol/L
TOC_F = num(:,25); % mmol/L

%%% standard deviation data
SD_bm = num(:,29);  % g/L
SD_glucose_out = num(:,30);  % mmol/L
SD_acetate_out= num(:,31); % mmol/L
SD_glycerol_out= num(:,32); % mmol/L
SD_lactate_out= num(:,33); % mmol/L
SD_ethanol_out= num(:,34); % mmol/L
SD_formate_out= num(:,35); % mmol/L
SD_succinate_out= num(:,36);  %mmol/L


%Balance of the gas phase
%The gas flow had two streams air and nitrogen, the same volume of gas in
%the reactor was kept
Fgas_out_Tot = ((Fair_in.*yN2air_in)+(Fnitrogen_in.*yN2nitrogen_in))./(1 - y_CO2_out -y_O2_out); % total flow of gas in the reactor

Fgas_out = Fair_in.*(1-yO2_in-yCO2_in)./(1 - y_CO2_out -y_O2_out) ; % only considering the air flow


figure(), bar([FNtotal Fgas_out_Tot]);
legend('F_{gas,in}','F_{gas,out}','Location','Best')
xlabel('Air (%)','FontSize',14)
ylabel('Gas flow (mmol/h)','FontSize',14)
set(gca,'XTickLabel',porcentFair')
% ylim([200 300]);

%Rates of the gas phase
R_O2 = ((Fgas_out_Tot.*y_O2_out)-(Fair_in.*yO2_in)); %mmol/h
R_CO2= ((Fgas_out_Tot.*y_CO2_out) -(Fair_in.*yCO2_in));  %mmol/h
q_CO2 = R_CO2./BM ;%mmol/cmol*h
q_O2 = R_O2./BM ;%mmol/cmol*h

%Respiratory coefficient 
%%
% *RQ*
RQ= q_CO2./q_O2  % for complete glucose combustion approx~1

RQ= R_CO2./R_O2  %

%%
    % *%%%Calculating* Rates 

%%%Liquid phase rates (mmol/h)
%through the general formula Ri=(Fout*Cout)-(Fin*Cin)
R_BM = F_out.*BM ; % biomass mmol/h
R_Glc = (F_out.*Glc_out)-(F_in.*Glc_in); % glucose mmol/h
R_PHB = F_out.*PHB;      % 3HB mmol/h
R_glyc = F_out.*Glyc;  % glycerol mmol/h
R_lac =  F_out.*Lac ; % lactate mmol/h
R_eth =  F_out.*Eth ; % ethanol mmol/h
R_ace =  F_out.*Ace ; % acetate mmol/h
R_For = F_out.*For ; % formate mmol/h
R_Suc = F_out.*Suc ; % succinate mmol/h
R_NH4 = (F_out.*N_out)-(F_in.*N_in); % mmolN/h
R_TOCt = (F_out.*TOC_T); %  mCmol/h
R_TOCf = (F_out.*TOC_F); %  mCmol/h


%Calculating qRates (mmol/Cmol*h)
%through the general formula qi= (Ri/Cx*V)
q_Glc = R_Glc./(BM*V_L);   % mmol/cmol*h
u= R_BM./(BM*V_L);  %  1/h Biomass rate
q_glyc = R_glyc./(BM*V_L); %mmol/cmol*h
q_PHB = R_PHB./(BM*V_L); %mmol/cmol*h
q_lac = R_lac./(BM*V_L) ; %mmol/cmol*h
q_eth = R_eth./(BM*V_L) ; %mmol/cmol*h
q_ace= R_ace./(BM*V_L)  ;%mmol/cmol*h
% q_CO2 = R_CO2./(BM*V_L) ;%mmol/cmol*h
% q_O2 = AAA./(BM*V_L);%mmol/cmol*h
q_for= R_For./(BM*V_L) ;% mmol/cmol*h
q_suc= R_Suc./(BM*V_L) ;% mmol/cmol*h
q_NH4= R_NH4./(BM*V_L) ;%mmol/cmol*h


%%%%----Calculating qRates for COBRA constraints (mmol/gCDW*h) 
q1_Glc = R_Glc./(BM_m*V_L);   %  mmol/gCDW*h
q_bm= R_BM./(BM_m*V_L);  %  1/h Biomass rate
q1_glyc = R_glyc./(BM_m*V_L); %mmol/gCDW*h
q1_PHB = R_PHB./(BM_m*V_L); %mmol/gCDW*h
q1_lac = R_lac./(BM_m*V_L) ; %mmol/gCDW*h
q1_eth = R_eth./(BM_m*V_L) ; %mmol/gCDW*h
q1_ace= R_ace./(BM_m*V_L)  ;%mmol/gCDW*h
% q1_CO2 = R_CO2./(BM_m*V_L) ;%mmol/gCDW*h
% q1_O2 = AAA./(BM_m*V_L);%mmol/gCDW*h
q1_for= R_For./(BM_m*V_L) ;% mmol/gCDW*h
q1_suc= R_Suc./(BM_m*V_L) ;% mmol/gCDW*h
q1_NH4= R_NH4./(BM_m*V_L) ;%mmol/gCDW*h

%%% RCO2 and RO2 calculated from the carbon and electron balances 
%CARBON BALANCE
C=(R_BM + 6*R_Glc + 4*R_PHB + 3*R_glyc + 2*R_eth + 3*R_lac + 2*R_ace + R_For + 4*R_Suc)*-1; % mmol/h RCO2
%ELECTRON BALANCE
e= (4.38*R_BM + 24*R_Glc + 18*R_PHB + 14*R_glyc + 12*R_eth + 12*R_lac + 8*R_ace + 2*R_For + 14*R_Suc)./4; % mmol/h RO2

%%%%---Calculating rates for COBRA mmol/g*h---
q_CO2_2 = C./(BM_m*V_L) ;  %mmol/gCDW*h
q_O2_2 = e./(BM_m*V_L);  %mmol/gCDW*h

%Yield of biomass
%%for E. coli (Taymaz et.al) approx ~0.4
y_bm= BM./(Glc_in*6);  % mCmolBM/mCmolGlc
y_u = BM_m./Glc; % g/g 

%Yield of PHB
PHB_S = q_PHB./q1_Glc ;

%%Calculating standard deviationsof the qrates( mmmol/g_GDW*h )

SD_q_BM = q_bm.*sqrt(((SD_bm./BM_m).^2)+(SD_bm./BM_m).^2);
% SD_q_o2 = sqrt(std((o2_balance)/mean(o2_balance))^2+(std(biomass_conc)/mean(biomass_conc))^2)*q_o2;
% SD_q_co2 = sqrt(std((co2_balance)/mean(co2_balance))^2+(std(biomass_conc)/mean(biomass_conc))^2)*q_co2;
SD_q_glucose = q1_Glc.*sqrt(((SD_glucose_out/Glc_in).^2)+(SD_bm./BM_m).^2);
SD_q_acetate = q1_ace.*sqrt(((SD_acetate_out./Ace).^2)+(SD_bm./BM_m).^2);
SD_q_succinate = q1_suc.*sqrt(((SD_succinate_out./Suc).^2)+(SD_bm./BM_m).^2);
SD_q_lactate = q1_lac.*sqrt(((SD_lactate_out./Lac).^2)+(SD_bm./BM_m).^2);
SD_q_formate = q1_for.*sqrt(((SD_formate_out./For).^2)+(SD_bm./BM_m).^2);
SD_q_glycerol = q1_glyc.*sqrt(((SD_glycerol_out./Glyc).^2)+(SD_bm./BM_m).^2);
SD_q_ethanol = q1_eth.*sqrt(((SD_ethanol_out./Eth).^2)+(SD_bm./BM_m).^2);
% SD_q_PHB = q_PHB.*sqrt(((SD_PHB_out./PHB).^2)+(SD_bm./BM_m).^2);


% RQ_std= sqrt(std((co2_balance)/mean(co2_balance))^2+(std(o2_balance)/mean(o2_balance))^2)*q_co2;
%%% ---DATA display in mmol/gcdw*h								
Print_Rates= [q_O2_2 q_CO2_2 q_bm  q1_Glc  q1_ace  q1_lac  q1_eth  q1_glyc  q1_for  q1_suc  q1_PHB]
variables={'bm' 'Glc' 'ace' 'lac' 'eth' 'glyc' 'for' 'suc' 'PHB'};
%standard deviation of rates
SD_all = [SD_q_BM SD_q_glucose SD_q_acetate SD_q_lactate SD_q_ethanol SD_q_glycerol SD_q_formate SD_q_succinate ]
