%%  Oxygen-Limited of the strain K12+pPHB
%% D 0.05
% Data Reconciliation at O2/S = 0.939
%% qrates mmol/gcdw h
clc
clear A_MT C Cx E E_in E_out gaps j J Mw q_m q_rec recovery S S_beta sd_q sd_qrec
variables={'oxygen'  'CO2'   'BM'  'glucose' 'acetate' 'lactate' 'ethanol' 'glycerol' 'formate' 'succinate' 'PHB'};    
     
      % 1   2   3    4  5    6    7   8  9    10  11
      % O2 CO2  BM  Glu Ace  Lac Eth Gly For Succ PHB
     E=[ 0  1   1    6   2    3    2   3   1   4   4  ;
        -4  0   4.38 24  8    12  12   14  2   14  18 ]; 
     
A_MT = diag(ones(size(E,2),1)); 
C = [E;A_MT];

%Molecular weight of 1 Cmol of biomass
%Mw=24.44;

q_m = [ -2.755	2.261	1.9943	-2.9334	1.4116	1.4128	0.1769	0.5382	1.5995	0.6696	0.0094]';

% check on C and e balance raw data

for j =1:size( E,1 )
E_in = E(j,:) * min( q_m, 0 );
E_out = E(j,:) * max( q_m, 0 );
recovery(j) = E_out ./ -E_in * 100;
gaps(j) = E_in + E_out;
end

% error of measurements
%% the std for O2 and CO2 will be around 5% and PHB OF 0.00001%

sd_q = [0.050 0.050 0.0505	-0.0533	0.0712	0.0446	0.0321	0.0327	0.0532	0.1492 0.0000001]';

S = diag( [1e-9*ones(2,1); sd_q.^2 ]);
q_rec = inv(C'*inv(S)*C)*C'*inv(S)*[0;0;q_m];

% check calculations

for j =1:size( E,1 )
E_in = E(j,:) * min( q_rec, 0 );
E_out = E(j,:) * max( q_rec, 0 );
recovery(j) = E_out ./ -E_in * 100;
gaps(j) = E_in + E_out;
end

% estimtate errors in beta 
J = inv(C'*inv(S)*C)*C'*inv(S); 
S_beta = J * S * J';

sd_qrec = diag( S_beta ).^0.5;

% show rate +/- error
disp (variables')
disp( 'rate +/- error' )
disp( [q_rec sd_qrec] )

%% Calculate OUR and RQ with reconciled data 

RQ= q_rec(2)/q_rec(1);
RQ_STD= sqrt(sd_qrec(2)/q_rec(2))^2+((sd_qrec(1))/(q_rec(1))^2)*RQ;

qO2_qS = q_rec(1)/q_rec(4);
qO2_qS_STD= sqrt(sd_qrec(1)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qO2_qS;
b = [qO2_qS qO2_qS_STD];

Cx= 1.4905 ;%g/L
Cx_std= 0.0494  ; %% g/L

Mx = 24.56;  %g/mol CH1.73N0.24O0.35S0.006P0.005 Nikerel 2010

Y_BM = (q_rec(3)*Mx)/(q_rec(4)*180);
Y_BM_std = ((sd_qrec(3)/q_rec(3))^2)+((sd_qrec(4)/q_rec(4))^2);


OUR = q_rec(1)* Cx; %% mmolO2/Lh
OUR_std = sqrt(sd_qrec(1)/q_rec(1))^2 + ((Cx_std/Cx)^2)*OUR;  %%%


a= [OUR OUR_std]
a1=[RQ RQ_STD ; Y_BM Y_BM_std]

% %Normalizing by products with their qO2/qS for the Figure 										
qAce_n = q_rec(5)/q_rec(4);
qLac_n = q_rec(6)/q_rec(4);			
qEth_n = q_rec(7)/q_rec(4);	
qGlyc_n = q_rec(8)/q_rec(4);
qFor_n = q_rec(9)/q_rec(4);
qSucc_n = q_rec(10)/q_rec(4);
qPHB_n = q_rec(11)/q_rec(4);

%Calculating standard deviations of ratio qby-p/qS
qAce_s = sqrt(sd_qrec(5)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qAce_n;
qLac_s = sqrt(sd_qrec(6)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qLac_n;			
qEth_s = sqrt(sd_qrec(7)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qEth_n;	
qGlyc_s = sqrt(sd_qrec(8)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qGlyc_n;
qFor_s = sqrt(sd_qrec(9)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qFor_n;
qSucc_s = sqrt(sd_qrec(10)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qSucc_n;
qPHB_s = sqrt(sd_qrec(11)/q_rec(1))^2+((sd_qrec(4))/(q_rec(4))^2)*qPHB_n;

N_by_p= [qAce_n  qLac_n qEth_n qGlyc_n qFor_n qSucc_n qPHB_n]'  %%mmol qi/qO2
N_by_p_s= [qAce_s  qLac_s qEth_s qGlyc_s qFor_n qSucc_s qPHB_s]'  %%mmol by-p/qS